==> ui-kit-0.5.3.tgz: package/controls/reveal/reveal.js <==
import {attachKeybinding, removeKeybindings} from 'ui-kit/scripts/keybinding.js'

export var initialState = {isActive: false};
export var displayName = 'Reveal';

exports.componentWillMount = function () {
  if (this.props.showMenuKeyBinding) {
    attachKeybinding(this.props.showMenuKeyBinding, this.showReveal);
  }
  if (this.props.hideMenuKeyBinding) {
    attachKeybinding(this.props.hideMenuKeyBinding, this.hideReveal);
  }
  if (this.props.toggleMenuKeyBinding) {
    attachKeybinding(this.props.toggleMenuKeyBinding, this.toggle);
  }
}

exports.toggle = function (evt) {
  this.state.isActive ?
    this.hideReveal(evt) :
    this.showReveal(evt);
};

exports.hideReveal = function (evt) {
  if (!this.state.isActive) return;
  if (evt) evt.stopPropagation();
  this.setState({isActive: false});
  window.removeEventListener('click', this.onWindowClick);
};

exports.showReveal = function (evt) {
  var self = this;
  if (this.state.isActive) return;
  this.setState({isActive: true});
  setTimeout(function () {
    window.addEventListener('click', self.onWindowClick);
  }, 0);
};

exports.onWindowClick = function(evt) {
  if (!this.isMounted()) return;
  var el = this.getDOMNode();
  if (el && !elContains(el, evt.target) || this.props.hideOnClick) {
    this.hideReveal();
  }
};

exports.componentWillUnmount = function () {
  window.removeEventListener('click', this.onWindowClick);
  removeKeybindings([this.props.showMenuKeyBinding, this.props.hideMenuKeyBinding, this.props.toggleMenuKeyBinding]);
};

function elContains (container, el) {
  var l = container.children.length;
  var i = 0;

  for (i; i < l; i+=1) {
    var child = container.children[i];
    if (child == el) {
      return true;
    } else if (child.children.length) {
      if (elContains(child, el)) {
        return true;
      }
    }
  }

  return false;
}

==> ui-kit-0.11.81.tgz: package/controls/reveal/reveal.js <==

exports.toggle = function (evt) {
  this.state.isActive ?
    this.hideReveal(evt) :
    this.showReveal(evt);
};

exports.hideReveal = function (evt) {
  if (!this.state.isActive || this.isLocked) return;
  if (evt) evt.stopPropagation();
  this.setState({isActive: false});
  this.cleanup();
};

exports.unlockAndHide = function () {
  this.isLocked = false;
  this.hideReveal();
}

exports.showReveal = function (evt) {
  var self = this;
  if (this.state.isActive) return;
  if (!this.isLocked && window.hideLockedReveal) window.hideLockedReveal();
  
  this.setState({isActive: true});
  setTimeout(function () {
    window.addEventListener('click', self.onWindowClick);
  }, 0);
};

exports.lockReveal = function () {
  if (window.hideLockedReveal) window.hideLockedReveal();
  window.hideLockedReveal = this.unlockAndHide;
  this.isLocked = true;
};

exports.onWindowClick = function(evt) {
  if (!this.isMounted()) return;
  var el = this.getDOMNode();
  if (el && !elContains(el, evt.target) || this.props.hideOnClick) {
    this.hideReveal();
  }
};

exports.componentWillUnmount = function () {
  this.cleanup();
};

exports.cleanup = function () {
  if (window.hideLockedReveal) window.hideLockedReveal;
  delete window.hideLockedReveal;
  window.removeEventListener('click', this.onWindowClick);
};

function elContains (container, el) {
  var l = container.children.length;
  var i = 0;

  for (i; i < l; i+=1) {
    var child = container.children[i];
    if (child == el) {
      return true;
    } else if (child.children.length) {
      if (elContains(child, el)) {
        return true;
      }
    }
  }

  return false;
};
